Learn R Programming

scUtils (version 0.1.0)

is_wholenumber: Check if number(s) is/are integers. In contrast to is.integer, is_wholenumber does not check the class but accepts all numbers that are integers with reasonable precision.

Description

Check if number(s) is/are integers. In contrast to is.integer, is_wholenumber does not check the class but accepts all numbers that are integers with reasonable precision.

Usage

is_wholenumber(x, tol = .Machine$double.eps^0.5)

Arguments

x

Number to test

tol

tolerance for testing